==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/body/impl/RequiredSignalBodySetImpl.java <==
package io.ciera.tool.sql.ooaofooa.body.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.body.BodySet;
import io.ciera.tool.sql.ooaofooa.body.RequiredSignalBody;
import io.ciera.tool.sql.ooaofooa.body.RequiredSignalBodySet;
import io.ciera.tool.sql.ooaofooa.body.impl.BodySetImpl;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.RequiredSignalSet;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.impl.RequiredSignalSetImpl;

import java.util.Arrays;
import java.util.List;


public class RequiredSignalBodySetImpl extends InstanceSet<RequiredSignalBodySet,RequiredSignalBody> implements RequiredSignalBodySet {

    // attributes
    @Override
    public void setId( UniqueId ref_Id ) throws XtumlException {
        for ( RequiredSignalBody requiredsignalbody : this ) requiredsignalbody.setId( ref_Id );
    }
    @Override
    public void setAction_ID( UniqueId ref_Action_ID ) throws XtumlException {
        for ( RequiredSignalBody requiredsignalbody : this ) requiredsignalbody.setAction_ID( ref_Action_ID );
    }


    // selections
    @Override
    public RequiredSignalSet R684_specifies_processing_for_RequiredSignal() throws XtumlException {
        RequiredSignalSet requiredsignalset = new RequiredSignalSetImpl();
        for ( RequiredSignalBody requiredsignalbody : this ) requiredsignalset.add( requiredsignalbody.R684_specifies_processing_for_RequiredSignal() );
        return requiredsignalset;
    }
    @Override
    public BodySet R698_is_a_Body() throws XtumlException {
        BodySet bodyset = new BodySetImpl();
        for ( RequiredSignalBody requiredsignalbody : this ) bodyset.add( requiredsignalbody.R698_is_a_Body() );
        return bodyset;
    }


    @Override
    public RequiredSignalBody nullElement() {
        return RequiredSignalBodyImpl.EMPTY_REQUIREDSIGNALBODY;
    }

    @Override
    public RequiredSignalBodySet emptySet() {
      return new RequiredSignalBodySetImpl();
    }

    @Override
    public RequiredSignalBodySet value() {
        return this;
    }

    @Override
    public List<RequiredSignalBody> elements() {
        return Arrays.asList(toArray(new RequiredSignalBody[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/body/impl/RequiredSignalBodySetImpl.java <==
package io.ciera.tool.sql.ooaofooa.body.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.body.BodySet;
import io.ciera.tool.sql.ooaofooa.body.RequiredSignalBody;
import io.ciera.tool.sql.ooaofooa.body.RequiredSignalBodySet;
import io.ciera.tool.sql.ooaofooa.body.impl.BodySetImpl;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.RequiredSignalSet;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.impl.RequiredSignalSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class RequiredSignalBodySetImpl extends InstanceSet<RequiredSignalBodySet,RequiredSignalBody> implements RequiredSignalBodySet {

    public RequiredSignalBodySetImpl() {
    }

    public RequiredSignalBodySetImpl(Comparator<? super RequiredSignalBody> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setAction_ID( UniqueId ref_Action_ID ) throws XtumlException {
        for ( RequiredSignalBody requiredsignalbody : this ) requiredsignalbody.setAction_ID( ref_Action_ID );
    }
    @Override
    public void setId( UniqueId ref_Id ) throws XtumlException {
        for ( RequiredSignalBody requiredsignalbody : this ) requiredsignalbody.setId( ref_Id );
    }


    // selections
    @Override
    public RequiredSignalSet R684_specifies_processing_for_RequiredSignal() throws XtumlException {
        RequiredSignalSet requiredsignalset = new RequiredSignalSetImpl();
        for ( RequiredSignalBody requiredsignalbody : this ) requiredsignalset.add( requiredsignalbody.R684_specifies_processing_for_RequiredSignal() );
        return requiredsignalset;
    }
    @Override
    public BodySet R698_is_a_Body() throws XtumlException {
        BodySet bodyset = new BodySetImpl();
        for ( RequiredSignalBody requiredsignalbody : this ) bodyset.add( requiredsignalbody.R698_is_a_Body() );
        return bodyset;
    }


    @Override
    public RequiredSignalBody nullElement() {
        return RequiredSignalBodyImpl.EMPTY_REQUIREDSIGNALBODY;
    }

    @Override
    public RequiredSignalBodySet emptySet() {
      return new RequiredSignalBodySetImpl();
    }

    @Override
    public RequiredSignalBodySet emptySet(Comparator<? super RequiredSignalBody> comp) {
      return new RequiredSignalBodySetImpl(comp);
    }

    @Override
    public RequiredSignalBodySet value() {
        return this;
    }

    @Override
    public List<RequiredSignalBody> elements() {
        return Arrays.asList(toArray(new RequiredSignalBody[0]));
    }

}
